@@ -18,7 +18,7 @@ class Accounts(SirenComponent):
         response = self.session.get(
             urljoin(
                 self._environment.accounts,
-                '/__api_v2/groups'
+                'api/identity/v2/groups'
             ),
             params={
                 'filter[0][value]': account_name,
