@@ -254,8 +254,8 @@ class DownloadDatafileTestCase(SdkIntegrationTestCase):
 
             # validate we got the expected calls
             self.s3_download_mock.assert_has_calls([
-                call("s3://dev-ihsm-dl-pkg-test/prefix/MSFT.csv", dest),
-                call("s3://dev-ihsm-dl-pkg-test/prefix/AAPL.csv", dest),
+                call(s3_path="s3://dev-ihsm-dl-pkg-test/prefix/MSFT.csv", destination=dest),
+                call(s3_path="s3://dev-ihsm-dl-pkg-test/prefix/AAPL.csv", destination=dest),
             ],
                 any_order=True
             )
@@ -486,3 +486,84 @@ class RegisterDatafileTestCase(SdkIntegrationTestCase):
                 '/var/abc/prefix/microsoft/AAPL.csv',
                 '/var/abc/prefix/microsoft/cortana/master.txt'
             ]
+
+    def test_download_datafile_returns_paths_where_files_were_downloaded(self):
+        download_file = MagicMock()
+
+        class TestS3Client(Client):
+            def __init__(self, *args):
+                super().__init__(*args)
+                self.s3_client.download_file = download_file
+
+            def _list_objects(self, bucket, prefix):
+                return [{
+                    'Key': prefix
+                }]
+
+        with patch('dli.client.components.datafile.Client',
+                   TestS3Client) as client, \
+                patch('dli.client.s3.os.makedirs') as makedirs_mock:
+            sample_data = os.path.join(
+                os.path.dirname(__file__),
+                'resources/stocks'
+            )
+
+            datafile = self.client.register_s3_datafile(
+                self.create_and_get_dataset_id(),
+                "test_download_datafile_should_keep_folder_structure_as_in_datafile",
+                [sample_data],
+                "prefix",
+                '2000-01-01'
+            )
+
+            returned_list_of_files = self.client.download_datafile(
+                datafile.datafile_id,'/var/abc/'
+            )
+
+            files_created = [
+                '/var/abc/prefix/readme.txt',
+                '/var/abc/prefix/microsoft/MSFT.csv',
+                '/var/abc/prefix/microsoft/AAPL.csv',
+                '/var/abc/prefix/microsoft/cortana/master.txt'
+            ]
+            assert returned_list_of_files == files_created
+
+    def test_flattened_download_datafile_returns_one_path(self):
+        download_file = MagicMock()
+
+        class TestS3Client(Client):
+            def __init__(self, *args):
+                super().__init__(*args)
+                self.s3_client.download_file = download_file
+
+            def _list_objects(self, bucket, prefix):
+                return [{
+                    'Key': prefix
+                }]
+
+        with patch('dli.client.components.datafile.Client',
+                   TestS3Client) as client, \
+                patch('dli.client.s3.os.makedirs') as makedirs_mock:
+            sample_data = os.path.join(
+                os.path.dirname(__file__),
+                'resources/stocks'
+            )
+
+            datafile = self.client.register_s3_datafile(
+                self.create_and_get_dataset_id(),
+                "test_download_datafile_should_flatten_folder_structure",
+                [sample_data],
+                "prefix",
+                '2000-01-01'
+            )
+
+            returned_list_of_files = self.client.download_datafile(
+                datafile.datafile_id, '/var/abc/', flatten=True)
+
+            files_created = [ # package_dataset_asof_filename
+                '/var/abc/readme.txt',
+                '/var/abc/MSFT.csv',
+                '/var/abc/AAPL.csv',
+                '/var/abc/master.txt'
+            ]
+            assert returned_list_of_files == files_created
